/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JDBCConnectionInfo.java 18499 2009-09-03 14:25:10Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.jdbcconnections.service;

import java.util.List;

/**
 * Data returned to the flex side with JDBC Connection info.
 * @author Florent Benoit
 */
public class JDBCConnectionInfo {

    /**
     * Id of the connection.
     */
    private int id = 0;

    /**
     * This connection his being used by openCount clients.
     */
    private int openCount = 0;

    /**
     * Connection is inactive ?
     */
    private boolean inactive = true;

    /**
     * Duration since getConnection() call.
     */
    private long duration = 0;

    /**
     * Transaction XID (if still busy)
     */
    private String transactionXid = null;

    /**
     * Age of the connection (when it has been created)
     */
    private long age = 0;

    /**
     * Transaction timeout.
     */
    private String transactionTimeout = null;

    /**
     * Threads of the getConnection() calls.
     */
    private List<ThreadInfo> openersThreadInfos = null;

    /**
     * Threads of the close() calls.
     */
    private List<ThreadInfo> closersThreadInfos = null;

    /**
     * @return id of connection.
     */
    public int getId() {
        return id;
    }

    /**
     * Sets the ID's connection.
     * @param id the given id
     */
    public void setId(final int id) {
        this.id = id;
    }

    /**
     * @return number of open's count
     */
    public int getOpenCount() {
        return openCount;
    }

    /**
     * Sets the number of opened count.
     * @param openCount the given value
     */
    public void setOpenCount(final int openCount) {
        this.openCount = openCount;
    }

    /**
     * @return true if connection is inactive
     */
    public boolean isInactive() {
        return inactive;
    }

    /**
     * Sets the inactive flag
     * @param inactive the given value
     */
    public void setInactive(final boolean inactive) {
        this.inactive = inactive;
    }

    /**
     *
     * @return the elapsed time since getConnection() call
     */
    public long getDuration() {
        return duration;
    }

    /**
     * Sets the elapsed time since getConnection() call
     * @param duration the given value
     */
    public void setDuration(final long duration) {
        this.duration = duration;
    }

    /**
     * @return the associated transaction XID
     */
    public String getTransactionXid() {
        return transactionXid;
    }

    /**
     * Sets the associated transaction XID
     * @param transactionXid the given XID
     */
    public void setTransactionXid(final String transactionXid) {
        this.transactionXid = transactionXid;
    }

    /**
     * @return elapsed time since creation of connection.
     */
    public long getAge() {
        return age;
    }

    /**
     * Sets the elapsed time since creation of connection.
     * @param age
     */
    public void setAge(final long age) {
        this.age = age;
    }

    /**
     * @return the transaction timeout
     */
    public String getTransactionTimeout() {
        return transactionTimeout;
    }

    /**
     * Sets the transaction timeout
     * @param transactionTimeout the given value
     */
    public void setTransactionTimeout(final String transactionTimeout) {
        this.transactionTimeout = transactionTimeout;
    }

    /**
     * @return the threads info of the getConnection() calls
     */
    public List<ThreadInfo> getOpenersThreadInfos() {
        return openersThreadInfos;
    }

    /**
     * Sets the threads info of the getConnection() calls
     * @param openersThreadInfos the given data
     */
    public void setOpenersThreadInfos(final List<ThreadInfo> openersThreadInfos) {
        this.openersThreadInfos = openersThreadInfos;
    }

    /**
     * @return the threads info of the close() calls
     */
    public List<ThreadInfo> getClosersThreadInfos() {
        return closersThreadInfos;
    }

    /**
     * Sets the threads info of the close() calls
     * @param closersThreadInfos the given data
     */
    public void setClosersThreadInfos(final List<ThreadInfo> closersThreadInfos) {
        this.closersThreadInfos = closersThreadInfos;
    }

}
